@@ -239,7 +239,7 @@ class _ShowUnCategorizedResources(ExtendedJavaWrapper):
 
 
 class _ShowPublicPipelines(ExtendedJavaWrapper):
-    def __init__(self,lang, version):
+    def __init__(self, lang, version):
         super(_ShowPublicPipelines, self).__init__(
             "com.johnsnowlabs.nlp.pretrained.PythonResourceDownloader.showPublicPipelines", lang, version)
 
@@ -249,6 +249,7 @@ class _ShowPublicModels(ExtendedJavaWrapper):
         super(_ShowPublicModels, self).__init__(
             "com.johnsnowlabs.nlp.pretrained.PythonResourceDownloader.showPublicModels", annotator, lang, version)
 
+
 class _ShowAvailableAnnotators(ExtendedJavaWrapper):
     def __init__(self):
         super(_ShowAvailableAnnotators, self).__init__(
@@ -439,3 +440,9 @@ class _LongformerTokenClassifierLoader(ExtendedJavaWrapper):
         super(_LongformerTokenClassifierLoader, self).__init__(
             "com.johnsnowlabs.nlp.annotators.classifier.dl.LongformerForTokenClassification.loadSavedModel", path,
             jspark)
+
+
+class _BertSequenceClassifierLoader(ExtendedJavaWrapper):
+    def __init__(self, path, jspark):
+        super(_BertSequenceClassifierLoader, self).__init__(
+            "com.johnsnowlabs.nlp.annotators.classifier.dl.BertForSequenceClassification.loadSavedModel", path, jspark)
